RESIDE-package: RESIDE: Rapid Easy Synthesis to Inform Data Extraction

RESIDE-packageR Documentation

RESIDE: Rapid Easy Synthesis to Inform Data Extraction

Description

logo

Assists researchers with planning analysis prior to obtaining data from Trusted Research Environments (TREs), also known as safe havens. Marginal distributions of one or more related data frames can be exported from a TRE and imported elsewhere, where data can be synthesised from them, with or without user specified correlations, by sampling from a multivariate cumulative distribution (copula). The International Stroke Trial (IST) is included as an example dataset under the ODC-By licence, Sandercock et al. (2011) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.7488/ds/104")}, Sandercock et al. (2011) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1186/1745-6215-12-101")}.

Details

[Experimental]

The RESIDE Package

This work was supported by the UKRI Strength in Places Fund (SIPF) Competition, #' project number 107140. The project title is SIPF The Living Laboratory driving economic growth in Glasgow through real world implementation of precision medicine.

Author(s)

Maintainer: Ryan Field ryan.field@glasgow.ac.uk (ORCID)

Authors:

Other contributors:

See Also

Useful links:


RESIDE documentation built on Oct. 1, 2026, 1:07 a.m.