| filter_variables | R Documentation |
Filters a list of data frames to only include specified variables
filter_variables(dfs, variables)
dfs |
A list of data frames |
variables |
A vector of variable names |
This function filters each data frame in the input list to only include the specified variables.
A list of data frames with only the specified variables
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.