get_missing_variables: Get Missing Variables

View source: R/utils.R

get_missing_variablesR Documentation

Get Missing Variables

Description

Returns a list of missing variables from a list of data frames

Usage

get_missing_variables(dfs, variables)

Arguments

dfs

A list of data frames

variables

A vector of variable names

Details

This function checks if each variable in the input vector is present in any of the data frames.

Value

A vector of missing variable names


RESIDE documentation built on Oct. 1, 2026, 1:07 a.m.