Create a correlation object
correlation.RdA helper function to create a correlation object
Details
This function is a helper function to create a correlation
object that can be used to specify correlations between variables
when synthesising data using the synthesise_data function.
Additional Arguments:
df_name: The name of the data frame containing both variables
df_name.x: The name of the data frame containing the first variable
df_name.y: The name of the data frame containing the second variable
factor_name.x: The name of the factor variable for the first variable
factor_name.y: The name of the factor variable for the second variable