| correlation | R Documentation |
A helper function to create a correlation object
correlation(x, y, rho, ...)
x |
The name of the first variable |
y |
The name of the second variable |
rho |
The correlation between the two variables |
... |
Additional arguments to specify data frame names and factor names See details for more information on the additional arguments. |
This function is a helper function to create a correlation
object that can be used to specify correlations between variables
when synthesising data using the synthesise_data function.
Additional Arguments:
df_name: The name of the data frame containing both variables
df_name.x: The name of the data frame containing the first variable
df_name.y: The name of the data frame containing the second variable
factor_name.x: The name of the factor variable for the first variable
factor_name.y: The name of the factor variable for the second variable
A list containing the correlation information
correlation("age", "bmi", 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.