| get_missing_variables | R Documentation |
Returns a list of missing variables from a list of data frames
get_missing_variables(dfs, variables)
dfs |
A list of data frames |
variables |
A vector of variable names |
This function checks if each variable in the input vector is present in any of the data frames.
A vector of missing variable names
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.