summary.RESIDE: summary.RESIDE

View source: R/summary.RESIDE.R

summary.RESIDER Documentation

summary.RESIDE

Description

S3 override for summary RESIDE

Usage

## S3 method for class 'RESIDE'
summary(object, ...)

Arguments

object

an object of class RESIDE

...

Other parameters currently none are used

Details

S3 Override for RESIDE Class, a higher level summary than print.RESIDE. For each data frame it gives the number of rows, subjects and variables, the number of each type of variable, the number of date variables and the number of variables with missing data.

Value

An object of class summary.RESIDE, a list containing overall, a data frame of the overall summary, and data_frames, a data frame with a row for each data frame.

See Also

print.RESIDE

Examples

summary(
  get_marginal_distributions(
    IST,
    variables = c(
      "SEX",
      "AGE",
      "ID14",
      "RSBP",
      "RATRIAL"
    )
  )
)

RESIDE documentation built on Oct. 1, 2026, 1:07 a.m.