View source: R/summary.RESIDE.R
| summary.RESIDE | R Documentation |
S3 override for summary RESIDE
## S3 method for class 'RESIDE'
summary(object, ...)
object |
an object of class RESIDE |
... |
Other parameters currently none are used |
S3 Override for RESIDE Class, a higher level summary than
print.RESIDE. For each data frame it gives the number of
rows, subjects and variables, the number of each type of variable, the
number of date variables and the number of variables with missing data.
An object of class summary.RESIDE, a list containing
overall, a data frame of the overall summary, and
data_frames, a data frame with a row for each data frame.
print.RESIDE
summary(
get_marginal_distributions(
IST,
variables = c(
"SEX",
"AGE",
"ID14",
"RSBP",
"RATRIAL"
)
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.